@@ -104,6 +104,9 @@ import com.openexchange.admin.tools.filestore.FilestoreDataMover;
 import com.openexchange.admin.tools.filestore.PostProcessTask;
 import com.openexchange.caching.Cache;
 import com.openexchange.caching.CacheService;
+import com.openexchange.config.cascade.ConfigProperty;
+import com.openexchange.config.cascade.ConfigView;
+import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.exception.OXException;
 import com.openexchange.filestore.FileStorages;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
@@ -162,7 +165,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         }
 
         final String[] mods = sModule.split(" *, *");
-        final Set<String> modules = new LinkedHashSet<String>(mods.length);
+        final Set<String> modules = new LinkedHashSet<>(mods.length);
         for (final String mod : mods) {
             modules.add(mod);
         }
@@ -206,7 +209,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             }
 
             final OXContextStorageInterface oxcox = OXContextStorageInterface.getInstance();
-            oxcox.changeQuota(ctx, new ArrayList<String>(modules), quota, auth);
+            oxcox.changeQuota(ctx, new ArrayList<>(modules), quota, auth);
         } catch (final StorageException e) {
             LOGGER.error("", e);
             throw e;
@@ -322,8 +325,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         }
         LOGGER.debug(ctx.toString());
 
-        Context backup_ctx = null; // used for invalidating old login mappings in the cache
-
+        Set<String> loginMappings = null; // used for invalidating old login mappings in the cache
         try {
             if (!tool.existsContext(ctx)) {
                 throw new NoSuchContextException();
@@ -352,8 +354,14 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                 }
             }
 
-            final OXContextStorageInterface oxcox = OXContextStorageInterface.getInstance();
-            backup_ctx = oxcox.getData(ctx);
+            OXContextStorageInterface oxcox = OXContextStorageInterface.getInstance();
+
+            // Check if login-mappings are supposed to be changed
+            if (null != ctx.getLoginMappings()) {
+                // Load old ones for invalidation purpose
+                loginMappings = oxcox.getLoginMappings(ctx);
+            }
+
             oxcox.change(ctx);
         } catch (final StorageException e) {
             LOGGER.error("", e);
@@ -369,9 +377,8 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         try {
             final ContextStorage cs = ContextStorage.getInstance();
             cs.invalidateContext(ctx.getId().intValue());
-            final Set<String> loginMappings = backup_ctx.getLoginMappings();
             if (loginMappings != null && !loginMappings.isEmpty()) {
-                for (final String loginMapping : loginMappings) {
+                for (String loginMapping : loginMappings) {
                     cs.invalidateLoginInfo(loginMapping);
                 }
             }
@@ -792,7 +799,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
 
             new BasicAuthenticator(context).doAuthentication(auth);
 
-            final List<Context> retval = new ArrayList<Context>();
+            final List<Context> retval = new ArrayList<>();
             boolean filled = true;
             for (final Context ctx : ctxs) {
                 if (!ctx.isListrun()) {
@@ -867,8 +874,8 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
 
             Filter<Context, Context> loader = null;
             Filter<Integer, Integer> filter = null;
-            final ArrayList<Filter<Context, Context>> loaderFilter = new ArrayList<Filter<Context, Context>>();
-            final ArrayList<Filter<Integer, Integer>> contextFilter = new ArrayList<Filter<Integer, Integer>>();
+            final ArrayList<Filter<Context, Context>> loaderFilter = new ArrayList<>();
+            final ArrayList<Filter<Integer, Integer>> contextFilter = new ArrayList<>();
 
             final PluginInterfaces pluginInterfaces = PluginInterfaces.getInstance();
             if (null != pluginInterfaces) {
@@ -931,7 +938,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             }
             final OXContextStorageInterface oxcox = OXContextStorageInterface.getInstance();
 
-            final List<Context> retval = new ArrayList<Context>();
+            final List<Context> retval = new ArrayList<>();
             final Context[] ret = oxcox.searchContextByDatabase(db);
             final List<Context> callGetDataPlugins = callGetDataPlugins(Arrays.asList(ret), auth, oxcox);
             if (null != callGetDataPlugins) {
@@ -965,7 +972,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                 throw new NoSuchFilestoreException();
             }
             final OXContextStorageInterface oxcox = OXContextStorageInterface.getInstance();
-            final List<Context> retval = new ArrayList<Context>();
+            final List<Context> retval = new ArrayList<>();
             final Context[] ret = oxcox.searchContextByFilestore(filestore);
             final List<Context> callGetDataPlugins = callGetDataPlugins(Arrays.asList(ret), auth, oxcox);
             if (null != callGetDataPlugins) {
@@ -1190,8 +1197,23 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         }
 
         Context ret = oxcox.create(ctx, admin_user, createaccess, schemaSelectStrategy == null ? getDefaultSchemaSelectStrategy() : schemaSelectStrategy);
+        final ConfigViewFactory viewFactory = AdminServiceRegistry.getInstance().getService(ConfigViewFactory.class);
+        if (viewFactory != null) {
+            ConfigView view;
+            try {
+                view = viewFactory.getView(admin_user.getId(), ctx.getId());
+                Boolean check = view.get("com.openexchange.imap.initWithSpecialUse", Boolean.class);
+                if (check != null && check) {
+                    ConfigProperty<Boolean> prop = view.property("user", "com.openexchange.mail.specialuse.check", Boolean.class);
+                    prop.set(Boolean.TRUE);
+                }
+            } catch (OXException e) {
+                LOGGER.error("Unable to set special use check property!");
+            }
+        }
 
         if (isAnyPluginLoaded()) {
+            PluginException pe = null;
             PluginInterfaces pluginInterfaces = PluginInterfaces.getInstance();
             if (null != pluginInterfaces) {
                 for (OXContextPluginInterface contextInterface : pluginInterfaces.getContextPlugins().getServiceList()) {
@@ -1199,18 +1221,22 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                         ret = contextInterface.postCreate(ret, admin_user, createaccess, auth);
                     } catch (PluginException e) {
                         LOGGER.error("", e);
-                        // callPluginMethod delete may fail here for what ever reason.
-                        // this must not prevent us from cleaning up the rest
-                        try {
-                            contextInterface.delete(ctx, auth);
-                        } catch (Exception e1) {
-                            LOGGER.error("", e);
-                        }
-                        oxcox.delete(ret);
-                        throw StorageException.wrapForRMI(e);
+                        pe = e;
                     }
                 }
             }
+            if (null != pe) {
+                // cleanup
+                for (final OXContextPluginInterface oxContextPlugin : pluginInterfaces.getContextPlugins().getServiceList()) {
+                    try {
+                        oxContextPlugin.delete(ctx, auth);
+                    } catch (final PluginException e) {
+                        LOGGER.error("", e);
+                    }
+                }
+                oxcox.delete(ret);
+                throw StorageException.wrapForRMI(pe);
+            }
         }
 
         return ret;
