@@ -122,7 +122,7 @@ public class Filestore2UserUtil {
     public static boolean isNotTerminated(AdminCacheExtended cache) throws StorageException {
         Connection con = null;
         try {
-            con = cache.getConnectionForConfigDB();
+            con = cache.getReadConnectionForConfigDB();
             return isNotTerminated(con);
         } catch (PoolException e) {
             throw new StorageException(e);
@@ -133,7 +133,7 @@ public class Filestore2UserUtil {
         } finally {
             if (null != con) {
                 try {
-                    cache.pushConnectionForConfigDB(con);
+                    cache.pushReadConnectionForConfigDB(con);
                 } catch (PoolException e) {
                     LOG.error("Pooling error", e);
                 }
@@ -152,7 +152,7 @@ public class Filestore2UserUtil {
     public static Set<UserAndContext> getUsersFor(int filestoreId, AdminCacheExtended cache) throws StorageException {
         Connection con = null;
         try {
-            con = cache.getConnectionForConfigDB();
+            con = cache.getReadConnectionForConfigDB();
 
             // Check if processing
             if (isNotTerminated(con)) {
@@ -169,7 +169,7 @@ public class Filestore2UserUtil {
         } finally {
             if (null != con) {
                 try {
-                    cache.pushConnectionForConfigDB(con);
+                    cache.pushReadConnectionForConfigDB(con);
                 } catch (PoolException e) {
                     LOG.error("Pooling error", e);
                 }
@@ -209,7 +209,7 @@ public class Filestore2UserUtil {
     public static int getUserCountFor(int filestoreId, AdminCache cache) throws StorageException {
         Connection con = null;
         try {
-            con = cache.getConnectionForConfigDB();
+            con = cache.getReadConnectionForConfigDB();
 
             // Check if processing
             if (isNotTerminated(con)) {
@@ -226,7 +226,7 @@ public class Filestore2UserUtil {
         } finally {
             if (null != con) {
                 try {
-                    cache.pushConnectionForConfigDB(con);
+                    cache.pushReadConnectionForConfigDB(con);
                 } catch (PoolException e) {
                     LOG.error("Pooling error", e);
                 }
@@ -257,7 +257,7 @@ public class Filestore2UserUtil {
     public static FilestoreCountCollection getUserCounts(AdminCacheExtended cache) throws StorageException {
         Connection con = null;
         try {
-            con = cache.getConnectionForConfigDB();
+            con = cache.getReadConnectionForConfigDB();
 
             // Check if processing
             if (isNotTerminated(con)) {
@@ -274,7 +274,7 @@ public class Filestore2UserUtil {
         } finally {
             if (null != con) {
                 try {
-                    cache.pushConnectionForConfigDB(con);
+                    cache.pushReadConnectionForConfigDB(con);
                 } catch (PoolException e) {
                     LOG.error("Pooling error", e);
                 }
@@ -322,7 +322,7 @@ public class Filestore2UserUtil {
         Connection con = null;
         boolean rollback = false;
         try {
-            con = cache.getConnectionForConfigDB();
+            con = cache.getWriteConnectionForConfigDB();
             if (false == tableExists(con, "filestore2user")) {
                 LOG.warn("Table \"filestore2user\" does not exist.");
                 return;
@@ -356,7 +356,7 @@ public class Filestore2UserUtil {
                 }
                 Databases.autocommit(con);
                 try {
-                    cache.pushConnectionForConfigDB(con);
+                    cache.pushWriteConnectionForConfigDB(con);
                 } catch (PoolException e) {
                     LOG.error("Pooling error", e);
                 }
@@ -376,7 +376,7 @@ public class Filestore2UserUtil {
         Connection con = null;
         boolean rollback = false;
         try {
-            con = cache.getConnectionForConfigDB();
+            con = cache.getWriteConnectionForConfigDB();
             if (false == tableExists(con, "filestore2user")) {
                 LOG.warn("Table \"filestore2user\" does not exist.");
                 return;
@@ -410,7 +410,7 @@ public class Filestore2UserUtil {
                 }
                 Databases.autocommit(con);
                 try {
-                    cache.pushConnectionForConfigDB(con);
+                    cache.pushWriteConnectionForConfigDB(con);
                 } catch (PoolException e) {
                     LOG.error("Pooling error", e);
                 }
@@ -429,7 +429,7 @@ public class Filestore2UserUtil {
         Connection con = null;
         boolean rollback = false;
         try {
-            con = cache.getConnectionForConfigDB();
+            con = cache.getWriteConnectionForConfigDB();
             if (false == tableExists(con, "filestore2user")) {
                 LOG.warn("Table \"filestore2user\" does not exist.");
                 return;
@@ -463,7 +463,7 @@ public class Filestore2UserUtil {
                 }
                 Databases.autocommit(con);
                 try {
-                    cache.pushConnectionForConfigDB(con);
+                    cache.pushWriteConnectionForConfigDB(con);
                 } catch (PoolException e) {
                     LOG.error("Pooling error", e);
                 }
@@ -484,7 +484,7 @@ public class Filestore2UserUtil {
         Connection con = null;
         boolean rollback = false;
         try {
-            con = cache.getConnectionForConfigDB();
+            con = cache.getWriteConnectionForConfigDB();
             if (false == tableExists(con, "filestore2user")) {
                 LOG.warn("Table \"filestore2user\" does not exist.");
                 return;
@@ -518,7 +518,7 @@ public class Filestore2UserUtil {
                 }
                 Databases.autocommit(con);
                 try {
-                    cache.pushConnectionForConfigDB(con);
+                    cache.pushWriteConnectionForConfigDB(con);
                 } catch (PoolException e) {
                     LOG.error("Pooling error", e);
                 }
@@ -540,7 +540,7 @@ public class Filestore2UserUtil {
         Connection con = null;
         boolean rollback = false;
         try {
-            con = adminCache.getConnectionForConfigDB();
+            con = adminCache.getWriteConnectionForConfigDB();
             if (false == tableExists(con, "filestore2user")) {
                 LOG.warn("Table \"filestore2user\" does not exist.");
                 return;
@@ -578,7 +578,7 @@ public class Filestore2UserUtil {
                 }
                 Databases.autocommit(con);
                 try {
-                    adminCache.pushConnectionForConfigDB(con);
+                    adminCache.pushWriteConnectionForConfigDB(con);
                 } catch (PoolException e) {
                     LOG.error("Pooling error", e);
                 }
