@@ -202,7 +202,7 @@ public class AdminCache {
         this.prop = new PropertyHandler(System.getProperties());
         configureAuthentication(); // disabling authentication mechs
         readMasterCredentials(service);
-        this.log.info("Init Cache");
+        log.info("Init Cache");
         initPool();
         this.adminCredentialsCache = new Hashtable<Integer, Credentials>();
         this.adminAuthMechCache = new Hashtable<Integer, String>();
@@ -422,14 +422,35 @@ public class AdminCache {
         return this.pool.pushConnectionForContextNoTimeout(contextId, con);
     }
 
+    /**
+     * Use {@link #getReadConnectionForConfigDB()} or {@link #getWriteConnectionForConfigDB()} instead.
+     */
+    @Deprecated
     public Connection getConnectionForConfigDB() throws PoolException {
         return this.pool.getConnectionForConfigDB();
     }
 
+    public Connection getReadConnectionForConfigDB() throws PoolException {
+        return this.pool.getReadConnectionForConfigDB();
+    }
+
+    public Connection getWriteConnectionForConfigDB() throws PoolException {
+        return this.pool.getWriteConnectionForConfigDB();
+    }
+
+    @Deprecated
     public boolean pushConnectionForConfigDB(final Connection con) throws PoolException {
         return this.pool.pushConnectionForConfigDB(con);
     }
 
+    public boolean pushWriteConnectionForConfigDB(final Connection con) throws PoolException {
+        return this.pool.pushWriteConnectionForConfigDB(con);
+    }
+
+    public boolean pushReadConnectionForConfigDB(final Connection con) throws PoolException {
+        return this.pool.pushReadConnectionForConfigDB(con);
+    }
+
     public int getServerId() throws PoolException {
         return this.pool.getServerId();
     }
@@ -660,6 +681,7 @@ public class AdminCache {
         }
     }
 
+    @Deprecated
     public void closeConfigDBSqlStuff(final Connection con, final PreparedStatement stmt, final ResultSet rs) {
         if (null != rs) {
             try {
@@ -671,6 +693,40 @@ public class AdminCache {
         closeConfigDBSqlStuff(con, stmt);
     }
 
+    public void closeConfigDBSqlStuff(final PreparedStatement stmt, final ResultSet rs) {
+        if (null != rs) {
+            try {
+                rs.close();
+            } catch (final SQLException e) {
+                log.error("Error closing resultset", e);
+            }
+        }
+        closeReadConfigDBSqlStuff(null, stmt);
+    }
+
+    public void closeReadConfigDBSqlStuff(final Connection con, final PreparedStatement stmt, final ResultSet rs) {
+        if (null != rs) {
+            try {
+                rs.close();
+            } catch (final SQLException e) {
+                log.error("Error closing resultset", e);
+            }
+        }
+        closeReadConfigDBSqlStuff(con, stmt);
+    }
+
+    public void closeWriteConfigDBSqlStuff(final Connection con, final PreparedStatement stmt, final ResultSet rs) {
+        if (null != rs) {
+            try {
+                rs.close();
+            } catch (final SQLException e) {
+                log.error("Error closing resultset", e);
+            }
+        }
+        closeWriteConfigDBSqlStuff(con, stmt);
+    }
+
+    @Deprecated
     public void closeConfigDBSqlStuff(final Connection con, final PreparedStatement stmt) {
         try {
             if (stmt != null) {
@@ -688,6 +744,40 @@ public class AdminCache {
         }
     }
 
+    public void closeReadConfigDBSqlStuff(final Connection con, final PreparedStatement stmt) {
+        try {
+            if (stmt != null) {
+                stmt.close();
+            }
+        } catch (final SQLException e) {
+            log.error("Error closing statement", e);
+        }
+        try {
+            if (con != null) {
+                pushReadConnectionForConfigDB(con);
+            }
+        } catch (final PoolException exp) {
+            log.error("Pool Error pushing connection to pool!", exp);
+        }
+    }
+
+    public void closeWriteConfigDBSqlStuff(final Connection con, final PreparedStatement stmt) {
+        try {
+            if (stmt != null) {
+                stmt.close();
+            }
+        } catch (final SQLException e) {
+            log.error("Error closing statement", e);
+        }
+        try {
+            if (con != null) {
+                pushWriteConnectionForConfigDB(con);
+            }
+        } catch (final PoolException exp) {
+            log.error("Pool Error pushing connection to pool!", exp);
+        }
+    }
+
     public void closeContextSqlStuff(final Connection con, final int context_id) {
         closeContextSqlStuff(con, context_id, false);
     }
